==> xl-react-components-0.16.62.tgz: package/app/pages/playground/test-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';

import RU from '../../utils/ramda-utils';

import DisplayComponent from '../sink/display-component';
import ToggleComponent from '../playground/toggle-component';
import {localeMessages} from '../../services/locale-service';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import DisplayModeComponent from './display-mode-component';
import {createExtraBindingSections} from './playground-utils';
import ApiButton from './api-button';
import './test-component.less';

export default class TestComponent extends PureComponent {
    static propTypes = {
        api: PropTypes.object,
        children: PropTypes.oneOfType([
            PropTypes.element,
            PropTypes.array
        ]),
        className: PropTypes.string,
        disabled: PropTypes.bool,
        displayMode: PropTypes.string,
        extraBindingSections: PropTypes.array,
        hiddenDisplayedComponents: PropTypes.array,
        message: xlMessageTypeProp,
        model: PropTypes.any,
        onModeChange: PropTypes.func,
        onModelChange: PropTypes.func,
        onSizeChange: PropTypes.func,
        pristine: PropTypes.oneOfType([
            PropTypes.bool,
            PropTypes.object
        ]),
        required: PropTypes.bool,
        showBindings: PropTypes.bool,
        showMessages: PropTypes.bool,
        size: PropTypes.string,
        toggleDisable: PropTypes.func,
        toggleRequired: PropTypes.func,
        toggleShowMessages: PropTypes.func,
        updateProps: PropTypes.func,
        valid: PropTypes.oneOfType([
            PropTypes.bool,
            PropTypes.object
        ])
    };

    onFocus = () => {
        RU.invoke('focus', [], this.props.api);
    };

    onResettingPristinity = () => {
        RU.invoke('resetPristinity', [], this.props.api);
    };

    render() {
        const {
            className,
            children,
            disabled,
            displayMode,
            extraBindingSections,
            hiddenDisplayedComponents,
            model,
            onModeChange,
            onModelChange,
            pristine,
            required,
            showBindings,
            showMessages,
            toggleDisable,
            toggleShowMessages,
            toggleRequired,
            updateProps,
            valid
        } = this.props;

        const nullIfHidden = (label, component) => {
            if (hiddenDisplayedComponents.includes(label)) {
                return null;
            }
            return component;
        };

        const toggleComponent = (handler, label, clazzName, checked = false) => nullIfHidden(label, handler ?
            <ToggleComponent checked={checked} clazzName={clazzName} handleToggle={handler} label={label}/> : null);

        const showDisplayComponent = (clazzName, label, value) =>
            nullIfHidden(label, <DisplayComponent className={clazzName} label={label} value={value}/>);

        const showDisplayModeComponent = () =>
            nullIfHidden(localeMessages.displayModeLabel,
                <DisplayModeComponent mode={displayMode} onModeChange={onModeChange}/>);

        const showApiComponent = () =>
            nullIfHidden(localeMessages.apiLabel, <div>
                <span className="label">{localeMessages.apiLabel}</span>
                <ApiButton
                    clazzName={'reset-pristinity-btn'}
                    handleClick={this.onResettingPristinity}
                    label={localeMessages.resetPristinityButton}
                />
                <ApiButton clazzName={'focus-btn'} handleClick={this.onFocus} label={localeMessages.focusLabel}/>
            </div>);

        const displayBindings = () => showBindings ? <div className="testBindings">
            {showDisplayComponent('model', localeMessages.modelLabel, model)}
            {showDisplayComponent('pristine', localeMessages.pristineLabel, pristine)}
            {showDisplayComponent('valid', localeMessages.validLabel, valid)}

            {toggleComponent(toggleDisable, localeMessages.disabledLabel, 'disabled', disabled)}
            {toggleComponent(toggleRequired, localeMessages.requiredLabel, 'required', required)}
            {toggleComponent(toggleShowMessages, localeMessages.showMessagesLabel, 'show-messages', showMessages)}
            {showDisplayModeComponent()}
            {showApiComponent()}
            {createExtraBindingSections(
                extraBindingSections,
                model,
                onModelChange,
                updateProps,
                this.props.api,
                model
            )}
        </div> : null;

        return <div className={className}>
            <div className="testComponent">
                {children}
            </div>
            {displayBindings()}
        </div>;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/pages/playground/test-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';

import RU from '../../utils/ramda-utils';

import DisplayComponent from '../sink/display-component';
import ToggleComponent from '../playground/toggle-component';
import {localeMessages} from '../../services/locale-service';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import DisplayModeComponent from './display-mode-component';
import {createExtraBindingSections} from './playground-utils';
import ApiButton from './api-button';
import './test-component.less';

export default class TestComponent extends PureComponent {
    static propTypes = {
        api: PropTypes.object,
        children: PropTypes.oneOfType([
            PropTypes.element,
            PropTypes.array
        ]),
        className: PropTypes.string,
        disabled: PropTypes.bool,
        displayMode: PropTypes.string,
        extraBindingSections: PropTypes.array,
        hiddenDisplayedComponents: PropTypes.array,
        message: xlMessageTypeProp,
        model: PropTypes.any,
        onModeChange: PropTypes.func,
        onModelChange: PropTypes.func,
        onSizeChange: PropTypes.func,
        pristine: PropTypes.oneOfType([
            PropTypes.bool,
            PropTypes.object
        ]),
        required: PropTypes.bool,
        showBindings: PropTypes.bool,
        showMessages: PropTypes.bool,
        size: PropTypes.string,
        toggleDisable: PropTypes.func,
        toggleRequired: PropTypes.func,
        toggleShowMessages: PropTypes.func,
        updateProps: PropTypes.func,
        valid: PropTypes.oneOfType([
            PropTypes.bool,
            PropTypes.object
        ])
    };

    onFocus = () => {
        RU.invoke('focus', [], this.props.api);
    };

    onResettingPristinity = () => {
        RU.invoke('resetPristinity', [], this.props.api);
    };

    render() {
        const {
            className,
            children,
            disabled,
            displayMode,
            extraBindingSections,
            hiddenDisplayedComponents,
            model,
            onModeChange,
            onModelChange,
            pristine,
            required,
            showBindings,
            showMessages,
            toggleDisable,
            toggleShowMessages,
            toggleRequired,
            updateProps,
            valid
        } = this.props;

        const nullIfHidden = (label, component) => {
            if (hiddenDisplayedComponents.includes(label)) {
                return null;
            }
            return component;
        };

        const toggleComponent = (handler, label, clazzName, checked = false) => nullIfHidden(label, handler ?
            <ToggleComponent checked={checked} clazzName={clazzName} handleToggle={handler} label={label}/> : null);

        const showDisplayComponent = (clazzName, label, value) =>
            nullIfHidden(label, <DisplayComponent className={clazzName} label={label} value={value}/>);

        const showDisplayModeComponent = () =>
            nullIfHidden(localeMessages.displayModeLabel,
                <DisplayModeComponent mode={displayMode} onModeChange={onModeChange}/>);

        const showApiComponent = () =>
            nullIfHidden(localeMessages.apiLabel, <div>
                <span className="label">{localeMessages.apiLabel}</span>
                <ApiButton
                    clazzName={'reset-pristinity-btn'}
                    handleClick={this.onResettingPristinity}
                    label={localeMessages.resetPristinityButton}
                />
                <ApiButton clazzName={'focus-btn'} handleClick={this.onFocus} label={localeMessages.focusLabel}/>
            </div>);

        const displayBindings = () => showBindings ? <div className="testBindings">
            {showDisplayComponent('model', localeMessages.modelLabel, model)}
            {showDisplayComponent('pristine', localeMessages.pristineLabel, pristine)}
            {showDisplayComponent('valid', localeMessages.validLabel, valid)}

            {toggleComponent(toggleDisable, localeMessages.disabledLabel, 'xl-disabled', disabled)}
            {toggleComponent(toggleRequired, localeMessages.requiredLabel, 'required', required)}
            {toggleComponent(toggleShowMessages, localeMessages.showMessagesLabel, 'show-messages', showMessages)}
            {showDisplayModeComponent()}
            {showApiComponent()}
            {createExtraBindingSections(
                extraBindingSections,
                model,
                onModelChange,
                updateProps,
                this.props.api
            )}
        </div> : null;

        return <div className={className}>
            <div className="testComponent">
                {children}
            </div>
            {displayBindings()}
        </div>;
    }
}
